Learn R Programming

DrBats (version 0.1.3)

W.QR: Build and decompose a low-rank matrix W

Description

Build and decompose a low-rank matrix from a matrix of eigenvectors and eigenvalues from principal component analysis

Usage

W.QR(U, lambda)

Arguments

U
a matrix of eigenvectors
lambda
a vector of corresponding eigenvalues

Value

  • W a low-rank matrix

    D the number of latent factors

    Q the orthogonal matrix of the W = QR matrix decomposition

    R the upper triangular matrix of the W = QR matrix decomposition

Examples

Run this code
res <- drbats.simul(N = 5, P = 100, t.range = c(5, 100), breaks = 8)
res.pca <- pca.Deville(res$X, res$t.simul, t.range = c(5, 100), breaks = 8)
Wres.pca <- W.QR(res.pca$U, res.pca$lambda)
Wres.pca

Run the code above in your browser using DataLab