Usage
drbats.simul(N = 10, P = 150, t.range = c(0, 1000), b.range = c(0.2,
0.4), c.range = c(0.6, 0.8), b.sd = 2, c.sd = 2, a.range = c(-0.4,
0.4), y.range = c(0, 10), amp = 10, per = 12, data.type = "sparse",
breaks = 15, sigma2 = 0.2, seed = NULL)
Arguments
N
integer number of functions to simulate (default = 10)
P
a number of observation times (default = 150)
t.range
a range of times in which to place the P observations (default = c(1, 1000))
b.range
a vector giving the range of values for the mean of the first mode (default b.range = c(0.2, 0.4))
c.range
a vector giving the range of values for the mean of the second mode (default c.range = c(0.6, 0.8))
b.sd
the standard deviation for the first mode (default b.sd = 2)
c.sd
the standard deviation for the second mode (default c.sd = 2)
a.range
a vector giving the range of values for the slope (default a.range = c(-0.4, 0.4))
y.range
a vector giving the range of values for the intercept (default y.range = c(0, 10))
amp
the amplitude of the cosine function (default = 10)
per
the periodicity of the cosine function (default = 12)
data.type
string indicating type of functions (options :sparse, sparse.tend, sparse.tend.cos)
breaks
number of breaks in the histogram basis
sigma2
the precision of the error terms (default = 0.2)
seed
integer specification of a seed (default = NULL)