powered by
histoProj(X, t, t.range, breaks)
X.count a matrix containing the number of observations used to build the projection onto the histogram basis
windows a vector containing the first time of each window of the histogram intervals
X.max the matrix of minimum values in each window
X.min the matrix of maximum values in each window
res <- drbats.simul(N = 5, P = 100, t.range = c(5, 100), breaks = 8) res.proj <- histoProj(res$X, res$t.simul, t.range = c(5, 100), breaks = 8) res.proj
Run the code above in your browser using DataLab