Learn R Programming

DrBats (version 0.1.3)

pca.Deville: Perform a PCA using Deville's method

Description

Perform a PCA using Deville's method

Usage

pca.Deville(X, t, t.range, breaks)

Arguments

X
a data matrix
t
a matrix of observation times corresponding to X
t.range
the range of observation times in vector form (ex. t.range = c(0, 1000))
breaks
integer number of histogram windows

Value

  • X.histo the matrix projected onto the histogram basis

    U.histo a matrix of eigenvectors in the histogram basis

    Cp a matrix of principal components

    lambda a vector of eigenvalues

    perc.lambda a vector of the percentage of total inertia explained by each principal component

References

JC Deville, "Methodes statisiques et numeriques de l'analyse harmonique", Annales de l'INSEE, 1974.

Examples

Run this code
res <- drbats.simul(N = 5, P = 100, t.range = c(5, 100), breaks = 8)
res.pca <- pca.Deville(res$X, res$t.simul, t.range = c(5, 100), breaks = 8)
res.pca

Run the code above in your browser using DataLab