Learn R Programming

DrBats (version 0.1.3)

pca.proj.Xt: PCA data projected onto a histogram basis

Description

PCA data projected onto a histogram basis

Usage

pca.proj.Xt(X, t, t.range = c(0, 1000), breaks = 15)

Arguments

X
the data matrix
t
the matrix of observation times
t.range
a vector specifying the observation time range (default : c(0, 1000))
breaks
the number of breaks in the histogram basis (default : breaks = 15)

Value

  • Xt.proj a matrix of projected observations

    U a matrix of eigenvectors

    lambda a vector of eigenvalues

    lambda.perc the percentage of inertia captured by each axis

Examples

Run this code
res <- drbats.simul(N = 5, P = 100, t.range = c(5, 100), breaks = 8)
pca.proj.Xt(res$X, res$t.simul, t.range = c(0, 100), breaks = 8)

Run the code above in your browser using DataLab