Learn R Programming

DrBats (version 0.1.3)

weighted.Deville: Perform a weighted PCA using Deville's method on a data matrix X that we project onto a histogram basis and weighted

Description

Perform a weighted PCA using Deville's method on a data matrix X that we project onto a histogram basis and weighted

Usage

weighted.Deville(X, t, t.range, breaks, Qp = NULL)

Arguments

X
a data matrix
t
a matrix of observation times corresponding to X
t.range
the range of observation times in vector form (ex. t.range = c(a, b))
breaks
integer number of histogram windows
Qp
a matrix of weights, if Qp = NULL the function specifies a diagonal weight matrix

Value

  • X.histo the matrix projected onto the histogram basis

    U.histo a matrix of eigenvectors in the histogram basis

    Cp a matrix of principal components

    lambda a vector of eigenvalues

    perc.lambda a vector of the percentage of total inertia explained by each principal component

Examples

Run this code
res <- drbats.simul(N = 5, P = 100, t.range = c(5, 100), breaks = 8)
res.weighted <- weighted.Deville(res$X, res$t.simul, t.range = c(5, 100), breaks = 8, Qp = NULL)
res.weighted

Run the code above in your browser using DataLab