Rdocumentation
powered by
Learn R Programming
DrBats (version 0.1.3)
main.modelFit: Main function to fit the Bayesian Latent Factor model
Description
Main function to fit the Bayesian Latent Factor model
Usage
main.modelFit(params, out.file, verbose = 1, obj.version)
Arguments
params
a list of parameters for the modelFit function, see modelFit help for details
out.file
the path to the file that will be saved
verbose
binary variable (default = 1)
obj.version
output version (eg. "1.1.plt")
Value
nothing