powered by
pca.Deville(X, t, t.range, breaks)
U.histo a matrix of eigenvectors in the histogram basis
Cp a matrix of principal components
lambda a vector of eigenvalues
perc.lambda a vector of the percentage of total inertia explained by each principal component
res <- drbats.simul(N = 5, P = 100, t.range = c(5, 100), breaks = 8) res.pca <- pca.Deville(res$X, res$t.simul, t.range = c(5, 100), breaks = 8) res.pca
Run the code above in your browser using DataLab